@@ -138,6 +138,7 @@ class Assistant:
     def __init__(self) -> None:
         self.logger = logging.getLogger(__name__)
         self._client = FletClient()
+        self._validations: Dict[str, Callable] = {}
 
         try:
             # Prevent logging from keywords that return results
@@ -154,10 +155,25 @@ class Assistant:
             pass
 
     def _add_closing_button(self, label="Submit") -> None:
-        def close(e):
-            self._client.page.window_destroy()
+        def validate_and_close(*_):
+            should_close = True
+            if not self._validations:
+                self._client.page.window_destroy()
+            for field_name, validation in self._validations.items():
+                if not validation:
+                    continue
+                error_message = validation(self._client.results[field_name])
+                if error_message:
+                    should_close = False
+                    self._client.page.add(Text(
+                        f"Error on field named '{field_name}: {error_message}",
+                        color=flet.colors.RED))
+                    self._client.page.update()
+            if should_close:
+                self._client.results["submit"] = label
+                self._client.page.window_destroy()
 
-        self._client.add_element(ElevatedButton(label, on_click=close))
+        self._client.add_element(ElevatedButton(label, on_click=validate_and_close))
 
     @keyword("Clear elements")
     def clear_elements(self) -> None:
@@ -204,12 +220,13 @@ class Assistant:
         if not isinstance(size, Size):
             size = Size(size)
 
-        if size == Size.Small:
-            self._client.add_element(element=Text(heading, style="headlineSmall"))
-        elif size == Size.Medium:
-            self._client.add_element(element=Text(heading, style="headlineMedium"))
-        elif size == Size.Large:
-            self._client.add_element(element=Text(heading, style="headlineLarge"))
+        size_dict = {
+            Size.Small: "headlineSmall",
+            Size.Medium: "headlineMedium",
+            Size.Large: "headlineLarge",
+        }
+
+        self._client.add_element(element=Text(heading, style=size_dict[size]))
 
     @keyword("Add text")
     def add_text(
@@ -341,7 +358,7 @@ class Assistant:
         if not resolved.exists():
             self.logger.warning("File does not exist: %s", resolved)
 
-        def open_file(e):
+        def open_file(*_):
             if platform.system() == "Windows":
                 os.startfile(resolved)  # type: ignore # pylint: disable=no-member
             elif platform.system() == "Darwin":
@@ -450,14 +467,13 @@ class Assistant:
         name: str,
         label: Optional[str] = None,
         placeholder: Optional[str] = None,
-        rows: Optional[int] = None,
+        validation: Union[Callable, str] = None
     ) -> None:
         """Add a text input element
 
         :param name:        Name of result field
         :param label:       Label for field
         :param placeholder: Placeholder text in input field
-        :param rows:        Number of input rows
 
         Adds a text field that can be filled by the user. The entered
         content will be available in the ``name`` field of the result.
@@ -466,9 +482,6 @@ class Assistant:
         to add a descriptive label and the ``placholder`` text can be given
         to act as an example of the input value.
 
-        If the ``rows`` argument is given as a number, the input is converted
-        into a larger text area input with the given amount of rows by default.
-
         Example:
 
         .. code-block:: robotframework
@@ -478,13 +491,14 @@ class Assistant:
             Add text input    message
             ...    label=Feedback
             ...    placeholder=Enter feedback here
-            ...    rows=5
             ${result}=    Run dialog
             Send feedback message    ${result.email}  ${result.message}
         """
         # TODO: Do this in a cleaner way. Workaround because we use on_change
         # handlers to record values, so default value otherwise will be missed
+        # TODO: Implement the rows support
         self._client.results[name] = placeholder
+        self._validations[name] = validation
 
         self._client.add_element(
             name=name, element=TextField(label=label, value=placeholder)
@@ -618,9 +632,9 @@ class Assistant:
             END
         """
 
-        def on_pick_result(e: FilePickerResultEvent):
-            if e.files:
-                self._client.results[str(name)] = list(map(lambda f: f.path, e.files))
+        def on_pick_result(event: FilePickerResultEvent):
+            if event.files:
+                self._client.results[str(name)] = [f.path for f in event.files]
 
         file_picker = FilePicker(on_result=on_pick_result)
         self._client.add_invisible_element(file_picker)
@@ -759,9 +773,7 @@ class Assistant:
             Log    User type should be: ${result.user_type}
         """
         options, default = to_options(options, default)
-        radios: List[Control] = list(
-            map(lambda option: Radio(value=option, label=option), options)
-        )
+        radios: List[Control] = [Radio(value=option, label=option) for option in options]
         radio_group = RadioGroup(content=Column(radios), value=default)
 
         self._client.add_element(Text(value=label))
@@ -808,7 +820,7 @@ class Assistant:
     def add_submit_buttons(
         self,
         buttons: Options,
-        default: Optional[str] = None,
+        default: Optional[str] = None
     ) -> None:
         """Add custom submit buttons
 
@@ -912,28 +924,30 @@ class Assistant:
         self._client.display_flet_window(**options)
         return self._client.results
 
-    @keyword("Refresh", tags=["dialog"])
-    def refresh(self):
+    @keyword("Refresh Dialog", tags=["dialog"])
+    def refresh_dialog(self):
         """Can be used to update UI elements when adding elements while dialog is running"""
         if self._client.page:
             self._client.update_elements(self._client.page)
         else:
-            raise Exception("No dialog open")
+            raise RuntimeError("No dialog open")
 
     @keyword("Add Button", tags=["dialog"])
     def add_button(
         self, label: str, function: Union[Callable, str], *args, **kwargs
     ) -> None:
         """
-        ``function`` should be a python function or a Robot keyword name, args and kwargs should be valid arguments for it.
+        ``function`` should be a python function or a Robot keyword name,
+        args and kwargs should be valid arguments for it.
         """
 
         # FIXME: add some progress bar
-        # TODO: either optional or mandatory feature to block other button function calls while one is
-        # being processed (perhaps by making the button disabled during execution?)
+        # TODO: either optional or mandatory feature to block other button function
+        # calls while one is being processed
+        # (perhaps by making the button disabled during execution?)
 
         # TODO: use logger.err and logger.debug
-        def on_click(event: ControlEvent):
+        def on_click(_):
             if isinstance(function, Callable):
                 try:
                     function(*args, **kwargs)
@@ -974,7 +988,7 @@ class Assistant:
 
         """
 
-        def on_click(event: ControlEvent):
+        def on_click(_):
             if isinstance(function, Callable):
                 try:
                     function(self._client.results)
